@@ -14,7 +14,7 @@ from typing import Optional, Any, List, Dict, Union, Callable, Sequence, Tuple
 
 from questionary.constants import (
     DEFAULT_STYLE,
-    SELECTED_POINTER,
+    DEFAULT_SELECTED_POINTER,
     INDICATOR_SELECTED,
     INDICATOR_UNSELECTED,
     INVALID_INPUT,
@@ -36,7 +36,8 @@ class Choice:
     Args:
         title: Text shown in the selection list.
 
-        value: Value returned, when the choice is selected.
+        value: Value returned, when the choice is selected. If this argument
+               is `None` or unset, then the value of `title` is used.
 
         disabled: If set, the choice can not be selected by the user. The
                   provided text is used to explain, why the selection is
@@ -48,7 +49,7 @@ class Choice:
     """
 
     title: FormattedText
-    """Dispay string for the choice"""
+    """Display string for the choice"""
 
     value: Optional[Any]
     """Value of the choice"""
@@ -68,7 +69,7 @@ class Choice:
         value: Optional[Any] = None,
         disabled: Optional[str] = None,
         checked: Optional[bool] = False,
-        shortcut_key: Optional[str] = None,
+        shortcut_key: Optional[Union[str, bool]] = True,
     ) -> None:
 
         self.disabled = disabled
@@ -83,9 +84,15 @@ class Choice:
             self.value = title
 
         if shortcut_key is not None:
-            self.shortcut_key = str(shortcut_key)
+            if isinstance(shortcut_key, bool):
+                self.auto_shortcut = shortcut_key
+                self.shortcut_key = None
+            else:
+                self.shortcut_key = str(shortcut_key)
+                self.auto_shortcut = False
         else:
             self.shortcut_key = None
+            self.auto_shortcut = True
 
     @staticmethod
     def build(c: Union[str, "Choice", Dict[str, Any]]) -> "Choice":
@@ -113,15 +120,21 @@ class Choice:
                 c.get("key"),
             )
 
+    def get_shortcut_title(self):
+        if self.shortcut_key is None:
+            return "-) "
+        else:
+            return "{}) ".format(self.shortcut_key)
+
 
 class Separator(Choice):
     """Used to space/separate choices group."""
 
     default_separator: str = "-" * 15
-    """The default seperator used if none is specified"""
+    """The default separator used if none is specified"""
 
     line: str
-    """The string being used as a seperator"""
+    """The string being used as a separator"""
 
     def __init__(self, line: Optional[str] = None) -> None:
         """Create a separator in a list.
@@ -180,7 +193,7 @@ class InquirerControl(FormattedTextControl):
     use_indicator: bool
     use_shortcuts: bool
     use_arrow_keys: bool
-    use_pointer: bool
+    pointer: Optional[str]
     pointed_at: int
     is_answered: bool
 
@@ -188,19 +201,21 @@ class InquirerControl(FormattedTextControl):
         self,
         choices: Sequence[Union[str, Choice, Dict[str, Any]]],
         default: Optional[Union[str, Choice, Dict[str, Any]]] = None,
+        pointer: Optional[str] = DEFAULT_SELECTED_POINTER,
         use_indicator: bool = True,
         use_shortcuts: bool = False,
+        show_selected: bool = False,
         use_arrow_keys: bool = True,
-        use_pointer: bool = True,
         initial_choice: Optional[Union[str, Choice, Dict[str, Any]]] = None,
         **kwargs: Any,
     ):
 
         self.use_indicator = use_indicator
         self.use_shortcuts = use_shortcuts
+        self.show_selected = show_selected
         self.use_arrow_keys = use_arrow_keys
-        self.use_pointer = use_pointer
         self.default = default
+        self.pointer = pointer
 
         if default is not None and default not in choices:
             raise ValueError(
@@ -239,8 +254,12 @@ class InquirerControl(FormattedTextControl):
             )
 
     def _is_selected(self, choice: Choice):
+        if isinstance(self.default, Choice):
+            compare_default = self.default == choice
+        else:
+            compare_default = self.default == choice.value
         return (
-            choice.checked or choice.value == self.default and self.default is not None
+            choice.checked or compare_default and self.default is not None
         ) and not choice.disabled
 
     def _assign_shortcut_keys(self):
@@ -262,7 +281,7 @@ class InquirerControl(FormattedTextControl):
 
         shortcut_idx = 0
         for c in self.choices:
-            if c.shortcut_key is None and not c.disabled:
+            if c.auto_shortcut and not c.disabled:
                 c.shortcut_key = available_shortcuts[shortcut_idx]
                 shortcut_idx += 1
 
@@ -304,14 +323,15 @@ class InquirerControl(FormattedTextControl):
             selected = choice.value in self.selected_options
 
             if index == self.pointed_at:
-                if self.use_pointer:
-                    tokens.append(("class:pointer", " {} ".format(SELECTED_POINTER)))
+                if self.pointer is not None:
+                    tokens.append(("class:pointer", " {} ".format(self.pointer)))
                 else:
-                    tokens.append(("class:text", "   "))
+                    tokens.append(("class:text", " " * 3))
 
                 tokens.append(("[SetCursorPosition]", ""))
             else:
-                tokens.append(("class:text", "   "))
+                pointer_length = len(self.pointer) if self.pointer is not None else 1
+                tokens.append(("class:text", " " * (2 + pointer_length)))
 
             if isinstance(choice, Separator):
                 tokens.append(("class:separator", "{}".format(choice.title)))
@@ -340,10 +360,7 @@ class InquirerControl(FormattedTextControl):
                     )
                 )
             else:
-                if self.use_shortcuts and choice.shortcut_key is not None:
-                    shortcut = "{}) ".format(choice.shortcut_key)
-                else:
-                    shortcut = ""
+                shortcut = choice.get_shortcut_title() if self.use_shortcuts else ""
 
                 if selected:
                     if self.use_indicator:
@@ -379,13 +396,16 @@ class InquirerControl(FormattedTextControl):
         for i, c in enumerate(self.choices):
             append(i, c)
 
-        if self.use_shortcuts:
-            tokens.append(
-                (
-                    "class:text",
-                    "  Answer: {}" "".format(self.get_pointed_at().shortcut_key),
-                )
+        if self.show_selected:
+            current = self.get_pointed_at()
+
+            answer = current.get_shortcut_title() if self.use_shortcuts else ""
+
+            answer += (
+                current.title if isinstance(current.title, str) else current.title[0][1]
             )
+
+            tokens.append(("class:text", "  Answer: {}".format(answer)))
         else:
             tokens.pop()  # Remove last newline.
         return tokens
